unit Strategy;

interface

uses
  DabEmployee;

type
  // Concrete strategies for wage and salary earners
  TWageStrategy = class(TPayStrategy)
  private
    FMonthlyPay : Double;
  protected
    function GetPayAmount : Double; override;
  public
    constructor Create(MonthlyPay : Double);
  end;


  TSalaryStrategy = class(TPayStrategy)
  private
    FYearlyPay : Double;
  protected
    function GetPayAmount : Double; override;
  public
    constructor Create(YearlyPay : Double);
  end;


implementation


{ TWageStrategy }

constructor TWageStrategy.Create(MonthlyPay : Double);
begin
  inherited Create;
  FMonthlyPay := MonthlyPay;
end;


function TWageStrategy.GetPayAmount : Double;
begin
  Result := FMonthlyPay;
end;


{ TSalaryStrategy }

constructor TSalaryStrategy.Create(YearlyPay : Double);
begin
  inherited Create;
  FYearlyPay := YearlyPay;
end;


function TSalaryStrategy.GetPayAmount : Double;
begin
  Result := FYearlyPay / 12;
end;


end.
